@@ -45,13 +45,15 @@ class HelpLayout(Layout):
                         G - [cyan]go to bottom[/cyan]
                 l → Enter - [cyan]select[/cyan]
                     Space - [cyan]select[/cyan]
-                  h ← Esc - [cyan]go back to parent object[/cyan]
+                      h ← - [cyan]go back to parent object[/cyan]
                       [ ] - [cyan]switch attribute type (public/private)[/cyan]
                       { } - [cyan]switch pane[/cyan]
                         p - [cyan]toggle full preview[/cyan]
                         d - [cyan]toggle full docstring[/cyan]
                         n - [cyan]toggle filter view[/cyan]
-                        c - [cyan]clear filters in filter view[/cyan]
+                        / - [cyan]open search filter[/cyan]
+                      Esc - [cyan]close[/cyan]
+                        c - [cyan]clear filters[/cyan]
                         o - [cyan]toggle stack view[/cyan]
                         f - [cyan]open fullscreen view[/cyan]
                         H - [cyan]open help page on selected attribute[/cyan]
